@@ -728,7 +728,8 @@ static void MergeVertsSlow(int piTriList_in_and_out[], const SMikkTSpaceContext
 
 static void GenerateSharedVerticesIndexListSlow(int piTriList_in_and_out[], const SMikkTSpaceContext * pContext, const int iNrTrianglesIn)
 {
-	int iNumUniqueVerts = 0, t=0, i=0;
+	int // iNumUniqueVerts = 0,
+	    t=0, i=0;
 	for (t=0; t<iNrTrianglesIn; t++)
 	{
 		for (i=0; i<3; i++)
@@ -762,7 +763,7 @@ static void GenerateSharedVerticesIndexListSlow(int piTriList_in_and_out[], cons
 
 			assert(bFound);
 			// if we found our own
-			if (index2rec == index) { ++iNumUniqueVerts; }
+			// if (index2rec == index) { ++iNumUniqueVerts; }
 
 			piTriList_in_and_out[offs] = index2rec;
 		}
@@ -1202,7 +1203,8 @@ static tbool GenerateTSpaces(STSpace psTspace[], const STriInfo pTriInfos[], con
 	STSpace * pSubGroupTspace = NULL;
 	SSubGroup * pUniSubGroups = NULL;
 	int * pTmpMembers = NULL;
-	int iMaxNrFaces=0, iUniqueTspaces=0, g=0, i=0;
+	int iMaxNrFaces=0, // iUniqueTspaces=0,
+	    g=0, i=0;
 	for (g=0; g<iNrActiveGroups; g++)
 		if (iMaxNrFaces < pGroups[g].iNrFaces)
 			iMaxNrFaces = pGroups[g].iNrFaces;
@@ -1222,7 +1224,7 @@ static tbool GenerateTSpaces(STSpace psTspace[], const STriInfo pTriInfos[], con
 	}
 
 
-	iUniqueTspaces = 0;
+	// iUniqueTspaces = 0;
 	for (g=0; g<iNrActiveGroups; g++)
 	{
 		const SGroup * pGroup = &pGroups[g];
@@ -1353,7 +1355,7 @@ static tbool GenerateTSpaces(STSpace psTspace[], const STriInfo pTriInfos[], con
 		// clean up and offset iUniqueTspaces
 		for (s=0; s<iUniqueSubGroups; s++)
 			free(pUniSubGroups[s].pTriMembers);
-		iUniqueTspaces += iUniqueSubGroups;
+		// iUniqueTspaces += iUniqueSubGroups;
 	}
 
 	// clean up
